@@ -10,7 +10,8 @@ class Town(Thing):
     house_width = 5
     house_length = 5
     house_height = 3
-    space = 3  # space between houses
+    space = 3
+    """space between the town houses"""
 
     def build(self):
         init_x = self.position.x
@@ -24,5 +25,13 @@ class Town(Thing):
             house.width = self.house_width
             house.length = self.house_length
             house.height = self.house_height
+            house.block = self.block
             house.build()
             house_pos.z += self.house_width + self.space
+
+        # Fill the end_position
+        end_x = init_x + self.house_length
+        end_y = init_y + self.house_height
+        end_z = house_pos.z - self.space
+
+        self._end_position = mcpi.vec3.Vec3(end_x, end_y, end_z)
